probnum.randvars
================

Random Variables.

Random variables generalize multi-dimensional arrays by encoding uncertainty
about the (numerical) quantity in question. Despite their name, they do not
necessarily represent stochastic objects. Random variables are also the primary in-
and outputs of probabilistic numerical methods.

.. automodapi:: probnum.randvars
    :no-heading:
    :no-main-docstr:
